# Generated by Django 3.2.4 on 2021-07-12 01:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0025_auto_20210710_2247"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="BP > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="BP > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="BP > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="BP > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="severe_htn",
            field=models.CharField(
                blank=True,
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="BP > 180/120mmHg",
                max_length=15,
                null=True,
                verbose_name="Does the patient have severe hypertension?",
            ),
        ),
    ]
