# Generated by Django 5.2.3 on 2025-07-03 22:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0065_alter_historicaloffstudymedication_subject_identifier_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicallosstofollowup",
            name="subject_identifier",
            field=models.CharField(db_index=True, max_length=50),
        ),
        migrations.AlterField(
            model_name="losstofollowup",
            name="subject_identifier",
            field=models.CharField(max_length=50, unique=True),
        ),
    ]
