# Generated by Django 5.2.1 on 2025-06-02 18:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0062_alter_endofstudy_offstudy_reason_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicaloffstudymedication",
            name="singleton_field",
            field=models.CharField(
                db_index=True,
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                verbose_name="subject identifier",
            ),
        ),
        migrations.AddField(
            model_name="offstudymedication",
            name="singleton_field",
            field=models.CharField(
                editable=False,
                help_text="auto updated for unique constraint",
                max_length=50,
                null=True,
                unique=True,
                verbose_name="subject identifier",
            ),
        ),
    ]
