# Generated by Django 5.2.1 on 2025-06-02 18:43

from django.db import migrations
from django.db.models import F


def update_singeton_field(apps, schema_editor):
    model_cls = apps.get_model("meta_prn.offstudymedication")
    model_cls.objects.update(singleton_field=F("subject_identifier"))


class Migration(migrations.Migration):

    dependencies = [
        ("meta_prn", "0063_historicaloffstudymedication_singleton_field_and_more"),
    ]

    operations = [migrations.RunPython(update_singeton_field)]
