# Generated by Django 5.0.8 on 2024-08-22 19:34

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0030_auto_20240822_1637"),
    ]

    operations = [
        migrations.CreateModel(
            name="EndpointsProxy",
            fields=[],
            options={
                "verbose_name": "Endpoints (DM): All",
                "verbose_name_plural": "Endpoints (DM): All",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("meta_reports.endpoints",),
        ),
    ]
