# Generated by Django 5.2.7 on 2025-10-14 00:10

import edc_model.models.fields.other_charfield
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0235_glucosefbg_endpoint_today_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalhivexitreview",
            name="other_current_arv_regimen",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalpatienthistory",
            name="other_current_arv_regimen",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="hivexitreview",
            name="other_current_arv_regimen",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
        migrations.AlterField(
            model_name="patienthistory",
            name="other_current_arv_regimen",
            field=edc_model.models.fields.other_charfield.OtherCharField(
                blank=True,
                default="",
                max_length=35,
                null=True,
                verbose_name="If other, please specify ...",
            ),
        ),
    ]
