# Generated by Django 5.2.10 on 2026-01-23 13:40

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0021_diagnosticdevices"),
        ("meta_subject", "0240_glucose_diagnostic_device_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="glucose",
            old_name="diagnostic_device",
            new_name="fbg_diagnostic_device",
        ),
        migrations.RenameField(
            model_name="glucosefbg",
            old_name="diagnostic_device",
            new_name="fbg_diagnostic_device",
        ),
        migrations.RenameField(
            model_name="historicalglucose",
            old_name="diagnostic_device",
            new_name="fbg_diagnostic_device",
        ),
        migrations.RenameField(
            model_name="historicalglucosefbg",
            old_name="diagnostic_device",
            new_name="fbg_diagnostic_device",
        ),
    ]
