# Generated by Django 3.2.4 on 2021-07-02 01:58

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0056_auto_20210702_0426"),
    ]

    operations = [
        migrations.AddField(
            model_name="bloodresultsglu",
            name="fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsglu",
            name="fasted_duration_minutes",
            field=models.IntegerField(help_text="system calculated value", null=True),
        ),
        migrations.AddField(
            model_name="bloodresultsglu",
            name="fasted_duration_str",
            field=models.CharField(
                blank=True,
                help_text="Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="fasted",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Has the participant fasted?",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="fasted_duration_minutes",
            field=models.IntegerField(help_text="system calculated value", null=True),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsglu",
            name="fasted_duration_str",
            field=models.CharField(
                blank=True,
                help_text="Duration of fast. Format is `HHhMMm`. For example 1h23m, 12h7m, etc",
                max_length=8,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^([0-9]{1,3}h([0-5]?[0-9]m)?)$",
                        message="Invalid format. Expected something like 1h20m, 11h5m, etc",
                    )
                ],
                verbose_name="How long have they fasted in hours and/or minutes?",
            ),
        ),
    ]
