# Generated by Django 5.2.3 on 2025-07-10 12:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0224_bloodresultsfbc_abnormal_summary_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="followupvitals",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
        migrations.AddField(
            model_name="historicalfollowupvitals",
            name="waist_circumference",
            field=models.DecimalField(
                blank=True,
                decimal_places=1,
                help_text="in centimeters",
                max_digits=5,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(50.0),
                    django.core.validators.MaxValueValidator(175.0),
                ],
                verbose_name="Waist circumference",
            ),
        ),
    ]
