# Generated by Django 5.2.6 on 2025-09-24 05:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0019_auto_20250128_0143"),
    ]

    operations = [
        migrations.AlterField(
            model_name="abnormalfootappearanceobservations",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="abnormalfootappearanceobservations",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="abnormalfootappearanceobservations",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="arvregimens",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="baselinesymptoms",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="baselinesymptoms",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="baselinesymptoms",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="complications",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="complications",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="complications",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="diabetessymptoms",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="diabetessymptoms",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="diabetessymptoms",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="dmmedications",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="dmmedications",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="dmmedications",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="dmtreatments",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="healthcareworkers",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="healthcareworkers",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="healthcareworkers",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="hypertensionmedications",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="hypertensionmedications",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="hypertensionmedications",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="investigations",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="investigations",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="investigations",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="missedreferralreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="missedreferralreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="missedreferralreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="nonadherencereasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="offstudyreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="oiprophylaxis",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="oiprophylaxis",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="oiprophylaxis",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissedreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="symptoms",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="symptoms",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="symptoms",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="extra_value",
            field=models.CharField(default="", max_length=250),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="field_name",
            field=models.CharField(
                blank=True,
                default="",
                editable=False,
                help_text="Not required",
                max_length=25,
            ),
        ),
        migrations.AlterField(
            model_name="transferreasons",
            name="plural_name",
            field=models.CharField(
                default="", max_length=250, verbose_name="Plural name"
            ),
        ),
    ]
