# Generated by Django 3.2.13 on 2022-08-26 01:06

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0142_auto_20220826_0322"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="bloodresultsfbc",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="bloodresultsglu",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="bloodresultshba1c",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="bloodresultsins",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="bloodresultslft",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="bloodresultslipid",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="bloodresultsrft",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="delivery",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="egfrdropnotification",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="followupexamination",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultsfbc",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultsglu",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultshba1c",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultsins",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultslft",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultslipid",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalbloodresultsrft",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicaldelivery",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalegfrdropnotification",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalfollowupexamination",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalsubjectvisitmissed",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="historicalurinepregnancy",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="subjectvisitmissed",
            name="tracking_identifier",
        ),
        migrations.RemoveField(
            model_name="urinepregnancy",
            name="tracking_identifier",
        ),
        migrations.AlterField(
            model_name="historicalsubjectvisitmissed",
            name="action_identifier",
            field=models.CharField(blank=True, db_index=True, max_length=50, null=True),
        ),
        migrations.AlterField(
            model_name="subjectvisitmissed",
            name="action_identifier",
            field=models.CharField(blank=True, max_length=50, null=True, unique=True),
        ),
    ]
