# Generated by Django 5.2.10 on 2026-01-22 19:43

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_lists", "0021_diagnosticdevices"),
        ("meta_subject", "0238_historicalhivexitreview_available_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="glucosefbg",
            name="diagnostic_device",
            field=models.ForeignKey(
                blank=True,
                limit_choices_to={"name__icontains": "FBG"},
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="meta_lists.diagnosticdevices",
            ),
        ),
        migrations.AddField(
            model_name="historicalglucosefbg",
            name="diagnostic_device",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                limit_choices_to={"name__icontains": "FBG"},
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="meta_lists.diagnosticdevices",
            ),
        ),
    ]
