# Generated by Django 5.2.6 on 2025-09-30 22:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("meta_rando", "0007_spfqlist"),
    ]

    operations = [
        migrations.DeleteModel(
            name="SpfqList",
        ),
    ]
