# Generated by Django 5.1 on 2024-10-09 16:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_reports", "0050_alter_endpoints_created"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="endpoints",
            name="baseline_datetime",
        ),
        migrations.RemoveField(
            model_name="endpoints",
            name="fbg_datetime",
        ),
        migrations.RemoveField(
            model_name="endpoints",
            name="offstudy_datetime",
        ),
        migrations.AddField(
            model_name="endpoints",
            name="baseline_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="endpoints",
            name="fbg_date",
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name="endpoints",
            name="offstudy_date",
            field=models.DateField(null=True),
        ),
    ]
