# Generated by Django 5.0.1 on 2024-02-12 22:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0017_complications_dmmedications_dmtreatments_and_more"),
        ("meta_subject", "0164_dmreferralfollowup_historicaldmreferralfollowup"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="healthcare_workers",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.healthcareworkers",
                verbose_name="What type of health care worker did you see?",
            ),
        ),
    ]
