# Generated by Django 3.2.11 on 2022-01-28 14:19

import django.core.validators
import django_crypto_fields.fields.firstname_field
import django_crypto_fields.fields.lastname_field
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_consent", "0006_auto_20210911_2036"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="first_name",
            field=django_crypto_fields.fields.firstname_field.FirstnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="last_name",
            field=django_crypto_fields.fields.lastname_field.LastnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="first_name",
            field=django_crypto_fields.fields.firstname_field.FirstnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="last_name",
            field=django_crypto_fields.fields.lastname_field.LastnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
    ]
