# Generated by Django 4.2.11 on 2024-05-15 23:16

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0190_dmdiagnosis_dx_no_tmg_reason_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmdiagnosis",
            name="dx_no_tmg_reason",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If NO, please explain why this case was not discussed with the TMG",
            ),
        ),
        migrations.AlterField(
            model_name="dmdiagnosis",
            name="dx_tmg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If YES, provide the date of the TMG discussion",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result date and time of FBG",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmdiagnosis",
            name="dx_no_tmg_reason",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If NO, please explain why this case was not discussed with the TMG",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmdiagnosis",
            name="dx_tmg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If YES, provide the date of the TMG discussion",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result date and time of FBG",
            ),
        ),
    ]
