# Generated by Django 3.2.4 on 2021-08-09 14:44

from django.db import migrations, models


class Migration(migrations.Migration):
    """Added as a fake. Needed it to repair a test DB"""

    dependencies = [
        ("meta_subject", "0073_auto_20210809_0055"),
    ]

    operations = []
