# Generated by Django 4.0.5 on 2022-07-03 13:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0039_historicaloffstudymedication_reason_other_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="expected_restart_date",
        ),
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="permanently_discontinued",
        ),
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="permanently_discontinued_reason",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="expected_restart_date",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="permanently_discontinued",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="permanently_discontinued_reason",
        ),
        migrations.AddField(
            model_name="endofstudy",
            name="investigator_decision",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If reason is `investigator decision`, please explain ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalendofstudy",
            name="investigator_decision",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If reason is `investigator decision`, please explain ...",
            ),
        ),
        migrations.AddField(
            model_name="historicaloffstudymedication",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Comment"),
        ),
        migrations.AddField(
            model_name="offstudymedication",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Comment"),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("diabetes", "Patient developed diabetes"),
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    ("toxicity", "Patient experienced an unacceptable toxicity"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                ],
                max_length=25,
                null=True,
                verbose_name="If withdrawn on CLINICAL grounds, please specify PRIMARY reason...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("diabetes", "Patient developed diabetes"),
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    ("toxicity", "Patient experienced an unacceptable toxicity"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                ],
                max_length=25,
                null=True,
                verbose_name="If withdrawn on CLINICAL grounds, please specify PRIMARY reason...",
            ),
        ),
    ]
