# Generated by Django 5.2.3 on 2025-07-24 03:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0226_followupvitals_waist_circumference_comment_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followupvitals",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
    ]
