# Generated by Django 3.2.11 on 2022-03-12 00:39

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0036_auto_20220304_2307"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="repeat_fbg_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first FBG measures",
                max_length=15,
                verbose_name="Was the FBG repeated?",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="repeat_ogtt_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                help_text="If repeated, must be at least 3 days after the first OGTT measures",
                max_length=15,
                verbose_name="Was the OGTT repeated?",
            ),
        ),
    ]
