# Generated by Django 4.2.11 on 2024-05-15 23:46

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0197_glucosefbg_fasting_duration_estimated_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="glucosefbg",
            name="fasting_duration_estimated",
            field=models.CharField(
                default="No",
                editable=False,
                help_text="Set to YES for existing values before duration question was added to the form, otherwise NO",
                max_length=15,
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="fasting_duration_estimated",
            field=models.CharField(
                default="No",
                editable=False,
                help_text="Set to YES for existing values before duration question was added to the form, otherwise NO",
                max_length=15,
            ),
        ),
    ]
