# Generated by Django 3.2.4 on 2021-07-10 16:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_screening", "0023_auto_20210702_0533"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalscreeningpartone",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectscreening",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AddField(
            model_name="subjectscreening",
            name="staying_nearby_12",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 12 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartone",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningpartthree",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalscreeningparttwo",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="staying_nearby",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                max_length=15,
                null=True,
                verbose_name="Is the patient planning to remain in the catchment area for at least 6 months",
            ),
        ),
    ]
