from .health_economics_simple_admin import HealthEconomicsSimpleAdmin
from .health_economics_update_admin import HealthEconomicsUpdateAdmin

__all__ = ["HealthEconomicsSimpleAdmin", "HealthEconomicsUpdateAdmin"]
