# Generated by Django 4.1.2 on 2022-11-30 18:01

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0157_remove_bloodresultsfbc_crf_status_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followupexamination",
            name="attended_clinic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Includes other routine appointments, e.g. BP check or family planning",
                max_length=25,
                verbose_name="Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason",
            ),
        ),
        migrations.AlterField(
            model_name="followupexamination",
            name="attended_clinic_detail",
            field=models.TextField(
                blank=True,
                help_text="If the participant was given a referral letter or discharge summary record details here",
                null=True,
                verbose_name="If YES, attend clinic or hospital, please provide details of this event",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="attended_clinic",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Includes other routine appointments, e.g. BP check or family planning",
                max_length=25,
                verbose_name="Since the participant's last study visit did they attend any clinic or hospital for care for ANY reason",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupexamination",
            name="attended_clinic_detail",
            field=models.TextField(
                blank=True,
                help_text="If the participant was given a referral letter or discharge summary record details here",
                null=True,
                verbose_name="If YES, attend clinic or hospital, please provide details of this event",
            ),
        ),
    ]
