# Generated by Django 5.2.6 on 2025-09-24 05:45

import django.utils.timezone
import django_revision.revision_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0031_alter_historicalsubjectconsent_guardian_name_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="ethnicity",
            field=models.CharField(
                default="", editable=False, help_text="from screening", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="ethnicity",
            field=models.CharField(
                default="", editable=False, help_text="from screening", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="consent_extension_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent extension definition",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="consent_extension_version",
            field=models.CharField(
                default="",
                editable=False,
                max_length=10,
                verbose_name="Consent extension version",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1ext",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectreconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="ethnicity",
            field=models.CharField(
                default="", editable=False, help_text="from screening", max_length=15
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="action_identifier",
            field=models.CharField(blank=True, default="", max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="consent_extension_definition_name",
            field=models.CharField(
                default="",
                editable=False,
                max_length=50,
                verbose_name="Consent extension definition",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="consent_extension_version",
            field=models.CharField(
                default="",
                editable=False,
                max_length=10,
                verbose_name="Consent extension version",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsentv1ext",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="action_identifier",
            field=models.CharField(blank=True, default="", max_length=50, unique=True),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="slug",
            field=models.CharField(
                db_index=True,
                default="",
                editable=False,
                help_text="Hold slug field values for quick search. Excludes encrypted fields",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="subjectreconsent",
            name="subject_identifier_aka",
            field=models.CharField(
                default="",
                editable=False,
                help_text="track a previously allocated identifier.",
                max_length=50,
                verbose_name="Subject Identifier a.k.a",
            ),
        ),
    ]
