# Generated by Django 3.2.13 on 2022-10-04 03:29

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0049_auto_20220929_1742"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, null=True, verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="historicaloffstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, null=True, verbose_name="If other, please specify ..."
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="comment",
            field=models.TextField(
                blank=True, null=True, verbose_name="Any additional comments"
            ),
        ),
        migrations.AlterField(
            model_name="offstudymedication",
            name="reason_other",
            field=models.TextField(
                blank=True, null=True, verbose_name="If other, please specify ..."
            ),
        ),
    ]
